==> haskell-yesod-1.4.5-109-i686.pkg.tar.xz: usr/share/haskell/register/haskell-yesod.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod
version: 1.4.5
id: yesod-1.4.5-31Fxg2b1exYAbyi10JAOa0
key: yesod-1.4.5-31Fxg2b1exYAbyi10JAOa0
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Yesod Yesod.Default.Config Yesod.Default.Config2
    Yesod.Default.Handlers Yesod.Default.Main Yesod.Default.Util
abi: c465d07a2c9ffdeff20c8827a714c946
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-1.4.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-1.4.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/yesod-1.4.5
hs-libraries: HSyesod-1.4.5-31Fxg2b1exYAbyi10JAOa0
depends:
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y base-4.10.0.0
    blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh
    blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL bytestring-0.10.8.2
    conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h
    conduit-extra-1.1.17-9f1YthVxnWoJohELB9cKUK
    data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp directory-1.3.0.2
    fast-logger-2.4.10-9IKpXM0932554g5cQqP0p7
    monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj
    monad-logger-0.3.25.1-CwaXwQJnYksLl9woJRYT1i
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    shakespeare-2.0.14-2RhgkLt2BZ2FcVRcUHxGbk
    streaming-commons-0.1.18-DO9CaqvVOYhDrA5bma8vy4
    template-haskell-2.12.0.0 text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    transformers-0.5.2.0 unix-2.7.2.2
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS
    wai-extra-3.0.20.0-3RsqWfyj5YW2l6djskzmjS
    wai-logger-2.3.0-9cV4zbM0jVb2n8dfPIJIxs
    warp-3.2.13-CqJVCwIbQDLAJvEXSHcVnZ
    yaml-0.8.23.3-AZSsApCdj2T3XfDE7MlqSi
    yesod-core-1.4.37-JuszFEIMgT7GCjtePdexVq
    yesod-form-1.4.16-3DIBswCz8s28DWo3MaJfVg
    yesod-persistent-1.4.2-EodKVwMp1Oz6gMlg9oUS5k
abi-depends: aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh=a026cdf45341163ef88f9856837f267f
             blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL=f07231ccbdf42fb50e1dae1144230e4a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h=52e9aaa2724a9edb2ade5ee067f8810a
             conduit-extra-1.1.17-9f1YthVxnWoJohELB9cKUK=56fd5c6de95125ae43c66f7b1cc14a76
             data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp=55d8edbe337279f21d58496f3f779cb9
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             fast-logger-2.4.10-9IKpXM0932554g5cQqP0p7=4fe9e3cb4687ed21d88fd96f3fa94e5f
             monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj=f1e3985ff4759dcc429559c38ecdf6c4
             monad-logger-0.3.25.1-CwaXwQJnYksLl9woJRYT1i=5ca2af848924c38076b16946ad67a1a4
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=aad58cc65045b8e62f1806217258d930
             shakespeare-2.0.14-2RhgkLt2BZ2FcVRcUHxGbk=c1be0c7e3aef06708629b91f4c947edf
             streaming-commons-0.1.18-DO9CaqvVOYhDrA5bma8vy4=e456784a917b058dfa9cbf83d08f1715
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             unix-2.7.2.2=53184c24da5ad45126d145b2febba63d
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS=b2b1b36770028b18814f7469d1a17fa5
             wai-extra-3.0.20.0-3RsqWfyj5YW2l6djskzmjS=1dff1369fdaa1f0b9ddfb5c9876e47e4
             wai-logger-2.3.0-9cV4zbM0jVb2n8dfPIJIxs=980351279c4942632d0628edb229e7b9
             warp-3.2.13-CqJVCwIbQDLAJvEXSHcVnZ=55b121d359036e442f9647dd16cddbb6
             yaml-0.8.23.3-AZSsApCdj2T3XfDE7MlqSi=7a6af61a5a6f451ce0540a63a6a62d32
             yesod-core-1.4.37-JuszFEIMgT7GCjtePdexVq=72517b26a25c829da3db516df501806a
             yesod-form-1.4.16-3DIBswCz8s28DWo3MaJfVg=a92ebd41641cc3e07eb6bb3a469c8570
             yesod-persistent-1.4.2-EodKVwMp1Oz6gMlg9oUS5k=acdcd10b4271c6b9c39560f69ca50467
haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
haddock-html: /usr/share/doc/haskell-yesod/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-1.4.5-111-i686.pkg.tar.xz: usr/share/haskell/register/haskell-yesod.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod
version: 1.4.5
id: yesod-1.4.5-BL8qfzVA7HTDI4F9rvxByM
key: yesod-1.4.5-BL8qfzVA7HTDI4F9rvxByM
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Yesod Yesod.Default.Config Yesod.Default.Config2
    Yesod.Default.Handlers Yesod.Default.Main Yesod.Default.Util
abi: 32efbff0976167dce3cc73e294b19464
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-1.4.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-1.4.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/yesod-1.4.5
hs-libraries: HSyesod-1.4.5-BL8qfzVA7HTDI4F9rvxByM
depends:
    aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq base-4.10.0.0
    blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh
    blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL bytestring-0.10.8.2
    conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h
    conduit-extra-1.1.17-9f1YthVxnWoJohELB9cKUK
    data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp directory-1.3.0.2
    fast-logger-2.4.10-9IKpXM0932554g5cQqP0p7
    monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj
    monad-logger-0.3.25.1-CwaXwQJnYksLl9woJRYT1i
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    shakespeare-2.0.14-ILbjPbZM5dUCAePhfgNGCi
    streaming-commons-0.1.18-DO9CaqvVOYhDrA5bma8vy4
    template-haskell-2.12.0.0 text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    transformers-0.5.2.0 unix-2.7.2.2
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS
    wai-extra-3.0.20.0-BsgGxPimsjqDT3aPQxdXol
    wai-logger-2.3.0-9cV4zbM0jVb2n8dfPIJIxs
    warp-3.2.13-CqJVCwIbQDLAJvEXSHcVnZ
    yaml-0.8.23.3-2QGOHBHHpaurEGLPcLVJG
    yesod-core-1.4.37-IhqUI9QzPQ77Qqbq9ysylY
    yesod-form-1.4.16-6TeOKMsOOPw96FM6oZpMde
    yesod-persistent-1.4.2-33vmuYxkFIF7qXbur5iq7b
abi-depends: aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq=8b90ef7c46d906c8047345fb433e32fe
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh=a026cdf45341163ef88f9856837f267f
             blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL=f07231ccbdf42fb50e1dae1144230e4a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h=52e9aaa2724a9edb2ade5ee067f8810a
             conduit-extra-1.1.17-9f1YthVxnWoJohELB9cKUK=56fd5c6de95125ae43c66f7b1cc14a76
             data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp=55d8edbe337279f21d58496f3f779cb9
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             fast-logger-2.4.10-9IKpXM0932554g5cQqP0p7=4fe9e3cb4687ed21d88fd96f3fa94e5f
             monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj=f1e3985ff4759dcc429559c38ecdf6c4
             monad-logger-0.3.25.1-CwaXwQJnYksLl9woJRYT1i=5ca2af848924c38076b16946ad67a1a4
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=aad58cc65045b8e62f1806217258d930
             shakespeare-2.0.14-ILbjPbZM5dUCAePhfgNGCi=5b0146feaa47ba68d8065943ed5853bc
             streaming-commons-0.1.18-DO9CaqvVOYhDrA5bma8vy4=e456784a917b058dfa9cbf83d08f1715
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             unix-2.7.2.2=53184c24da5ad45126d145b2febba63d
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS=b2b1b36770028b18814f7469d1a17fa5
             wai-extra-3.0.20.0-BsgGxPimsjqDT3aPQxdXol=257c1745e31e44c67121831897e26666
             wai-logger-2.3.0-9cV4zbM0jVb2n8dfPIJIxs=980351279c4942632d0628edb229e7b9
             warp-3.2.13-CqJVCwIbQDLAJvEXSHcVnZ=55b121d359036e442f9647dd16cddbb6
             yaml-0.8.23.3-2QGOHBHHpaurEGLPcLVJG=2c546b36221194a2b134d5137464910f
             yesod-core-1.4.37-IhqUI9QzPQ77Qqbq9ysylY=225bd3d3bf1b6f44c066e4dbef19d5d8
             yesod-form-1.4.16-6TeOKMsOOPw96FM6oZpMde=903e40c68005cc0735b8def77f5460d9
             yesod-persistent-1.4.2-33vmuYxkFIF7qXbur5iq7b=fa3014fdf287059af7b1df75cfec233c
haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
haddock-html: /usr/share/doc/haskell-yesod/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
